@@ -47,6 +47,7 @@ Archive::Archive(RAROptions *InitCmd)
   NewArchive=false;
 
   SilentOpen=false;
+
 }
 
 
@@ -130,8 +131,8 @@ bool Archive::IsArchive(bool EnableBroken)
   }
   else
   {
-    Array<char> Buffer(0x80000);
-    long CurPos=int64to32(Tell());
+    Array<char> Buffer(MAXSFXSIZE);
+    long CurPos=(long)Tell();
     int ReadSize=Read(&Buffer[0],Buffer.Size()-16);
     for (int I=0;I<ReadSize;I++)
       if (Buffer[I]==0x52 && IsSignature((byte *)&Buffer[I]))
@@ -180,16 +181,33 @@ bool Archive::IsArchive(bool EnableBroken)
   Protected=(NewMhd.Flags & MHD_PROTECT)!=0;
   Encrypted=(NewMhd.Flags & MHD_PASSWORD)!=0;
 
+  if (NewMhd.EncryptVer>UNP_VER)
+  {
+#ifdef RARDLL
+    Cmd->DllError=ERAR_UNKNOWN_FORMAT;
+#else
+    ErrHandler.SetErrorCode(WARNING);
+  #if !defined(SILENT) && !defined(SFX_MODULE)
+      Log(FileName,St(MUnknownMeth),FileName);
+      Log(FileName,St(MVerRequired),NewMhd.EncryptVer/10,NewMhd.EncryptVer%10);
+  #endif
+#endif
+    return(false);
+  }
 #ifdef RARDLL
   SilentOpen=true;
 #endif
+
+  //if not encrypted, we'll check it below
+  NotFirstVolume=Encrypted && (NewMhd.Flags & MHD_FIRSTVOLUME)==0;
+
   if (!SilentOpen || !Encrypted)
   {
     SaveFilePos SavePos(*this);
-    Int64 SaveCurBlockPos=CurBlockPos,SaveNextBlockPos=NextBlockPos;
+    int64 SaveCurBlockPos=CurBlockPos,SaveNextBlockPos=NextBlockPos;
 
     NotFirstVolume=false;
-    while (ReadHeader())
+    while (ReadHeader()!=0)
     {
       int HeaderType=GetHeaderType();
       if (HeaderType==NEWSUB_HEAD)
@@ -212,6 +230,12 @@ bool Archive::IsArchive(bool EnableBroken)
     CurBlockPos=SaveCurBlockPos;
     NextBlockPos=SaveNextBlockPos;
   }
+  if (!Volume || !NotFirstVolume)
+  {
+    strcpy(FirstVolumeName,FileName);
+    strcpyw(FirstVolumeNameW,FileNameW);
+  }
+
   return(true);
 }
 
@@ -239,3 +263,5 @@ int Archive::GetRecoverySize(bool Required)
 #endif
 
 
+
+
