@@ -29,6 +29,19 @@ size_t Archive::SearchSubBlock(const char *Type)
 }
 
 
+void Archive::UnexpEndArcMsg()
+{
+  int64 ArcSize=FileLength();
+  if (CurBlockPos>ArcSize || NextBlockPos>ArcSize)
+  {
+#ifndef SHELL_EXT
+    Log(FileName,St(MLogUnexpEOF));
+#endif
+    ErrHandler.SetErrorCode(WARNING);
+  }
+}
+
+
 size_t Archive::ReadHeader()
 {
   CurBlockPos=Tell();
@@ -48,7 +61,10 @@ size_t Archive::ReadHeader()
     return(0);
 #else
     if (Read(HeadersSalt,SALT_SIZE)!=SALT_SIZE)
+    {
+      UnexpEndArcMsg();
       return(0);
+    }
     if (*Cmd->Password==0)
 #ifdef RARDLL
       if (Cmd->Callback==NULL ||
@@ -73,14 +89,7 @@ size_t Archive::ReadHeader()
   Raw.Read(SIZEOF_SHORTBLOCKHEAD);
   if (Raw.Size()==0)
   {
-    int64 ArcSize=FileLength();
-    if (CurBlockPos>ArcSize || NextBlockPos>ArcSize)
-    {
-  #ifndef SHELL_EXT
-      Log(FileName,St(MLogUnexpEOF));
-  #endif
-      ErrHandler.SetErrorCode(WARNING);
-    }
+    UnexpEndArcMsg();
     return(0);
   }
 
@@ -169,11 +178,15 @@ size_t Archive::ReadHeader()
 
         if (hd->HeadType==NEWSUB_HEAD)
         {
+          // Let's calculate the size of optional data.
           int DataSize=hd->HeadSize-hd->NameSize-SIZEOF_NEWLHD;
           if (hd->Flags & LHD_SALT)
             DataSize-=SALT_SIZE;
+
           if (DataSize>0)
           {
+            // Here we read optional additional fields for subheaders.
+            // They are stored after the file name and before salt.
             hd->SubData.Alloc(DataSize);
             Raw.Get(&hd->SubData[0],DataSize);
             if (hd->CmpName(SUBHEAD_TYPE_RR))
@@ -569,7 +582,7 @@ void Archive::ConvertAttributes()
           }
           else
           {
-            // uname does not set +x for regular files, so we use 0666
+            // umask does not set +x for regular files, so we use 0666
             // instead of 0777 as for directories.
             NewLhd.FileAttr=0666 & ~mask;
           }
