@@ -66,6 +66,7 @@ bool ErrorHandler::AskRepeatRead(const char *FileName)
 #if !defined(SILENT) && !defined(SFX_MODULE) && !defined(_WIN_CE)
   if (!Silent)
   {
+    SysErrMsg();
     mprintf("\n");
     Log(NULL,St(MErrRead),FileName);
     return(Ask(St(MRetryAbort))==1);
@@ -105,6 +106,7 @@ bool ErrorHandler::AskRepeatWrite(const char *FileName,bool DiskFull)
 #if !defined(SILENT) && !defined(_WIN_CE)
   if (!Silent)
   {
+    SysErrMsg();
     mprintf("\n");
     Log(NULL,St(DiskFull ? MNotEnoughDisk:MErrWrite),FileName);
     return(Ask(St(MRetryAbort))==1);
@@ -286,7 +288,7 @@ void _stdfunction ProcessSignal(int SigType)
     Sleep(100);
 #endif
   }
-#if defined(USE_RC) && !defined(SFX_MODULE) && !defined(_WIN_CE)
+#if defined(USE_RC) && !defined(SFX_MODULE) && !defined(_WIN_CE) && !defined(RARDLL)
   ExtRes.UnloadDLL();
 #endif
   exit(USER_BREAK);
