@@ -16,11 +16,13 @@ void RAROptions::Init()
 {
   memset(this,0,sizeof(RAROptions));
   WinSize=0x400000;
-  Overwrite=OVERWRITE_ASK;
+  Overwrite=OVERWRITE_DEFAULT;
   Method=3;
   MsgStream=MSG_STDOUT;
   ConvertNames=NAMES_ORIGINALCASE;
   ProcessEA=true;
   xmtime=EXTTIME_HIGH3;
-  NextVolNum=0;
+  CurVolNum=0;
+  FileSizeLess=INT64NDF;
+  FileSizeMore=INT64NDF;
 }
